@@ -1,4 +1,5 @@
 from pynhost import utilities
+from pynhost import dynamic
 
 OPENING_TOKEN_DICT = {
     '(': 'list',
@@ -25,12 +26,13 @@ class RulePiece:
 
 class Rule:
     def __init__(self, raw_text, dictionary=None, actions=None, grammar=None):
+        if not isinstance(actions, list):
+            actions = [actions]
         self.actions = actions
         self.raw_text = raw_text
         self.pieces = parse(raw_text)
         self.grammar = grammar
         self.dictionary = dictionary
-        self.matching_words = None
 
     def __str__(self):
         return '<Rule: {}>'.format(self.raw_text)
