@@ -2,6 +2,7 @@ import subprocess
 import configparser
 import argparse
 import os
+import shutil
 import re
 import sys
 import pynhost
@@ -102,3 +103,23 @@ def get_logging_config():
         return log_file, int(log_level)
     except:
         return None, None
+
+def get_tags(pieces, tag_name, matches=None):
+    if matches is None:
+        matches = []
+    for piece in pieces:
+        if isinstance(piece, str):
+            continue
+        if piece.mode == 'num':
+            matches.append(piece.current_text)
+        else:
+            get_tags(piece.children, tag_name, matches)
+    return matches
+
+    def clear_directory(dir_path):
+        for filename in os.listdir(dir_path):
+            file_path = os.path.join(dir_path, filename)
+            if os.path.isfile(file_path):
+                os.unlink(file_path)
+            elif os.path.isdir(file_path):
+                shutil.rmtree(file_path)
\ No newline at end of file
